# What's Changed

> 📢 在升级前，请完整阅读本次更新日志。

## ✨ 新增的功能

1. 上线 MCP 市场(beta) @Soulter
2. MCP 服务器支持通过 SSE 连接 @Soulter
3. 支持自定义 PyPI 软件仓库地址 @Soulter
4. 支持开关是否忽略自身发送的消息 @Soulter
5. Docker 镜像自带 node 环境以适应 MCP 需要 @Soulter
6. 添加对 Gemini 原生搜索功能的支持 @Raven95676
7. 企业微信添加长文本分割功能以支持发送超过 2048 字符的消息 @Soulter @anka-afk
8. TTS 支持同时输出原始文本 @YOO-koishi

## 🎈 功能性优化

1. shared_preferences加载失败时自动删除无效文件 @Raven95676
2. 适配 MCP 配置文件带 mcpServers 的情况(Cursor) @Soulter
3. 采用 google-genai SDK 重构 Gemini 适配器 @Raven95676 @Soulter
4. 优化已安装的插件页，支持以列表展示 @Soulter
5. 分段回复优化 @huirh @Raven95676
6. 优化 MCP 服务器的日志回显 @Soulter
7. 为不支持流式输出的平台提供 Fallback @Raven95676
8. 替换为采用 Semver 语义化版本来比较版本号 @Soulter
9. 文件发送时支持路径映射 @Jackxwb

## 🐛 修复的 Bug

1. 修复关闭/删除 MCP 服务器后 Tools 没有清除的问题 @Soulter
2. 修复超出最大对话数时每次清除的消息比实际上期望的多 1 条 的问题 @Raila23
3. 修复调用函数工具可能导致 400 Bad Request 的问题 @Raila23
4. 修复飞书适配器无法发送 Base64 图片的问题 @KimigaiiWuyi @Soulter
5. 修复上下文带图的情况下，对话数据库页无法查看对话详情的问题 @Soulter
6. Telegram 适配器注册指令功能优化 @Raven95676
7. 修复阿里云百炼 TTS 只能发送一次语音，第二次就会报错 @Soulter

## 🧩 新增的插件

> Automatically generated by program.

- [Plugin] 60秒国内新闻 by @bbpn-cn in #970
- [Plugin] astrbot_plugin_memelite by @Zhalslar in #977
- [Plugin] 赛博打胶 by @tenno1174 in #980
- [Plugin] astrbot_plugin_PockAttack by @LouieKH359 in #981
- [Plugin] astrbot_plugin_saris_economic by @chengcheng0325 in #984
- [Plugin] astrbot_plugin_saris_db by @chengcheng0325 in #985
- [Plugin] astrbot_plugin_today_in_history by @Zhalslar in #987
- [Plugin] astrbot_plugin_history_day by @Zhalslar in #989
- [Plugin] astrbot_plugin_nachoneko by @Rinyin in #991
- [Plugin] jmcomicsget by @Ayachi2225 in #993
- [Plugin] astrbot_plugin_idiom by @zhx8702 in #994
- [Plugin] anime_gacha by @xco2 in #997
- [Plugin] jmcomic_downloader by @QiChenSn in #1007
- [Plugin] gewe_chatsummary by @NiceAir in #1013
- [Plugin] 群CCB by @tenno1174 in #1016
- [Plugin] 自动生成图表(思维导图、流程图等) by @kterna in #1018
- [Plugin] astrbot_plugin_jm_sender by @EnderPPT in #1019
- [Plugin] 插件名random image by @IGCrystal in #1021
- [Plugin] astrbot_plugin_saris_fish by @chengcheng0325 in #1022
- [Plugin] astrbot_plugin_membercontrast by @laopanmemz in #1027
- [Plugin] jm_search by @Ryonnoski0 in #1028
- [Plugin] astrbot_plugin_gomoku by @zhx8702 in #1029
- [Plugin] astrbot_plugin_CounterStrikle by @Last-emo-boy in #1036
- [Plugin] encrypt-and-decrypt by @Soffd in #1037
- [Plugin] emoji合成 by @ttq7 in #1041
- [Plugin] astrbot_plugin_file_reader by @xiewoc in #1043
- [Plugin] vv_pic by @LonelySky7490 in #1048
- [Plugin] bot代戳 by @791819 in #1049
- [Plugin] astrbot_plugin_weather_wttr_in by @xiewoc in #1051
- [Plugin] astrbot_plugin_kahunabot by @AraragiEro in #1053
- [Plugin] astrbot_plugin_answerbook by @litsum in #1058
- [Plugin] astrbot_plugin_ewords by @IGCrystal in #1059
- [Plugin] minecraft投影管理器 by @kterna in #1064
- [Plugin] minecraft投影管理器 by @kterna in #1063
- [Plugin] astrbot_plugin_encipherer by @Soffd in #1066
- [Plugin] 定时任务提醒插件 by @advent259141 in #1068
- [Plugin] 定时任务提醒插件 by @advent259141 in #1067
- [Plugin] bot_plugin_doro_today by @Futureppo in #1071
- [Plugin] JmCli by @gaxiic in #1076
- [Plugin] 用户自定义识别nickname by @MR-pofeng in #1078
- [Plugin] astrbot_plugin_timtip by @IGCrystal in #1082
- [Plugin] y @caomeiguodong in #1083
- [Plugin] astrbot_plugin_search_pic by @lyjlyjlyjly in #1084
- [Plugin] ot_plugin_quote_collocter by @litsum in #1089
- [Plugin] astrbot_plugin_ending by @clfpwp in #1090
- [Plugin] astrbot_plugin_GPT_SoVITS by @Zhalslar in #1091
- [Plugin] astrbot_plugin_Merge_WeMSG by @zj591227045 in #1092
- [Plugin] 随机维什戴尔游戏日语语音的AstrBot插件 by @zhewang448 in #1094
- [Plugin] astrbot_plugin_QQProfile by @Zhalslar in #1095
- [Plugin] astrbot_plugin_mcping by @Zhalslar in #1097
- [Plugin] astrbot_plugin_lorebook_lite by @Raven95676 in #1098
- [Plugin] astrbot_plugin_grok_filter by @Cheng-MaoMao in #1099
- [Plugin] astrbot_plugin_quarksave by @lm379 in #1100
- [Plugin] daily_limit by @left666 in #1102
- [Plugin] 赛博塔罗牌 by @XziXmn in #1103
- [Plugin] 把QQ里面不可保存的表情转化为可以保存的插件astrbot_plugins_ConvetPicture by @orchidsziyou in #1115
- [Plugin] astrbot_plugin_get_weather_cmd by @whzcc in #1117
- [Plugin] httpposter by @Wayzinx in #1118
- [Plugin] astrbot_plugin_get_weather_msg by @whzcc in #1119
- [Plugin] astrbot_plugin_cs2-box by @bvzrays in #1124
- [Plugin] astrbot_plugin_liars_bar by @xunxiing in #1125
- [Plugin] astrbot_plugin_cs2-box by @bvzrays in #1129
- [Plugin] astrbot_plugin_no_dragon_lord by @anka-afk in #1130
- [Plugin] astrbot_plugin_liars_bar by @xunxiing in #1134
- [Plugin] astrbot_plugin_QQAdmin  by @Zhalslar in #1137
- [Plugin] astrbot_plugin_SessionFaker by @advent259141 in #1138
- [Plugin] astrbot_plugin_browser by @Zhalslar in #1140
- [Plugin] astrbot_plugin_aishit by @advent259141 in #1141
- [Plugin] Arch Linux 软件包搜索插件 by @xmengnet in #1142
- [Plugin] astrbot_plugin_composting_bucket by @Rail1bc in #1147
- [Plugin] 任务管理task-management by @zengweis in #1149
- [Plugin] astrbot_plugin_appreview by @qiqi55488 in #1151
- [Plugin] doro互动故事 by @ttq7 in #1153
- [Plugin] 斗牛牛 by @LaoZhuJackson in #1155
- [Plugin] astrbot_plugin_reread by @Zhalslar in #1162
- [Plugin] astrbot_plugin_media302-save by @Qoo-330ml in #1163
- [Plugin] astrbot_plugin_ehentai_bot by @drdon1234 in #1168
- [Plugin] 追番助手（AGE） by @xiamuceer-j in #1181
- [Plugin] astrbot_plugin_zanwo by @Futureppo in #1183
- [Plugin] astrbot_plugin_jrrp by @exusiaiwei in #1189
- [Plugin] astrbot_plugin_group_chatsummary by @glidersxu in #1193
- [Plugin] astrbot_plugin_showmejm by @drdon1234 in #1202
- [Plugin] astrbot_plugin_gscore_adapter by @KimigaiiWuyi in #1206
- [Plugin] astrbot_portainer_plugin by @RC-CHN in #1209
- [Plugin] astrbot_plugin_goldprice by @waterfeet in #1210
- [Plugin] astrbot_plugin_xyzw by @XuYingJie-cmd in #1213
- [Plugin] astrbot_plugin_alist by @yukikazechan in #1217
- [Plugin] astrbot_plugin_showme_xjj by @drdon1234 in #1219
- [Plugin] astrbot_plugin_60s_news by @flyinsz in #1220
- [Plugin] astrbot_plugin_mp by @EWEDLCM in #1229
- [Plugin] 浅草寺抽签插件-PRO by @xiamuceer-j in #1230
- [Plugin] astrbot_plugin_gallery by @Zhalslar in #1238
- [Plugin] astrbot_plugin_openweaponscase by @luooka in #1250
- [Plugin] 多功能插件 by @ttq7 in #1254
- [Plugin] astrbot_plugin_douyin_bot by @drdon1234 in #1255
- [Plugin] astrbot_plugin_password by @Zhalslar in #1262
- [Plugin] FavorSystem by @wuyan1003 in #1264
- [Plugin] astrbot_plugin_ExchangeRateQuery by @MoonShadow1976 in #1271
- [Plugin] astrbot_plugin_pexels by @xiamuceer-j in #1278
- [Plugin] astrbot_plugin_hello-bye by @tinkerbellqwq in #1279
- [Plugin] astrbot_plugin_gotify by @BetaCatX in #1283
- [Plugin] astrbot_plugin_ccb_plus by @Koikokokokoro in #1287
- [Plugin] astrbot-gold-plugin by @RC-CHN in #1299
- [Plugin] 幻影坦克 by @bigshabei in #1305
- [Plugin] astrbot_plugin_repeat_after_me by @0d00-Ciallo-0721 in #1306
- [Plugin] astrbot_plugin_video by @guowenye in #1307
- [Plugin] astrbot_plugin_group_sum_ai by @Ayu-u in #1308
- [Plugin] 五子棋 by @bigshabei in #1309
- [Plugin] 舔狗日记 by @bigshabei in #1310
- [Plugin] astrbot_plugin_status-pro by @tinkerbellqwq in #1312
- [Plugin] 监听/转发 by @Cedar2352 in #1322
- [Plugin] astrbot_plugin_fuck by @vmoranv in #1338
- [Plugin] 食物推荐插件 by @Wayzinx in #1331
- [Plugin] astrbot_plugin_llmgo by @advent259141 in #1332
- [Plugin] astrbot_plugin_a2s by @ZvZPvz in #1337
